pub(crate) struct Exception {
exnref: VMExceptionRef,
}Expand description
A WebAssembly exnref in the sys runtime.
Fields
exnref: VMExceptionRefImplementations
Sourceimpl Exception
impl Exception
Sourcepub fn new(store: &mut impl AsStoreMut, tag: &Tag, payload: &[Value]) -> Self
pub fn new(store: &mut impl AsStoreMut, tag: &Tag, payload: &[Value]) -> Self
Creates a new exception with the given tag and payload, and also creates a reference to it, returning the reference.
pub fn exnref(&self) -> VMExceptionRef
pub fn from_exnref(exnref: VMExceptionRef) -> Self
pub fn is_from_store(&self, store: &impl AsStoreRef) -> bool
pub fn tag(&self, store: &impl AsStoreRef) -> Tag
pub fn payload(&self, store: &mut impl AsStoreMut) -> Vec<Value>