pub struct AsyncFunctionEnvMut<T> {
pub(crate) store: AsyncFunctionEnvMutStore,
pub(crate) func_env: FunctionEnv<T>,
}Expand description
A shared handle to a FunctionEnv, suitable for use
in async imports.
Fields
store: AsyncFunctionEnvMutStorefunc_env: FunctionEnv<T>Implementations
Sourceimpl<T: 'static> AsyncFunctionEnvMut<T>
impl<T: 'static> AsyncFunctionEnvMut<T>
pub(crate) fn store_id(&self) -> StoreId
Sourcepub async fn read(&self) -> AsyncFunctionEnvHandle<T>
pub async fn read(&self) -> AsyncFunctionEnvHandle<T>
Waits for a store lock and returns a read-only handle to the function environment.
Sourcepub async fn write(&self) -> AsyncFunctionEnvHandleMut<T>
pub async fn write(&self) -> AsyncFunctionEnvHandleMut<T>
Waits for a store lock and returns a mutable handle to the function environment.
Sourcepub fn as_ref(&self) -> FunctionEnv<T>
pub fn as_ref(&self) -> FunctionEnv<T>
Borrows a new immmutable reference
Sourcepub fn as_store_async(&self) -> impl AsStoreAsync + 'static
pub fn as_store_async(&self) -> impl AsStoreAsync + 'static
Creates an AsStoreAsync from this AsyncFunctionEnvMut.