Enum Architecture

#[non_exhaustive]
pub enum Architecture {
Show 35 variants Unknown, Arm(ArmArchitecture), AmdGcn, Aarch64(Aarch64Architecture), Asmjs, Avr, Bpfeb, Bpfel, Hexagon, X86_32(X86_32Architecture), M68k, LoongArch64, Mips32(Mips32Architecture), Mips64(Mips64Architecture), Msp430, Nvptx64, Pulley32, Pulley64, Pulley32be, Pulley64be, Powerpc, Powerpc64, Powerpc64le, Riscv32(Riscv32Architecture), Riscv64(Riscv64Architecture), S390x, Sparc, Sparc64, Sparcv9, Wasm32, Wasm64, X86_64, X86_64h, XTensa, Clever(CleverArchitecture),
}
The “architecture” field, which in some cases also specifies a specific subarchitecture.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown



Arm(ArmArchitecture)



AmdGcn



Aarch64(Aarch64Architecture)



Asmjs



Avr



Bpfeb



Bpfel



Hexagon



X86_32(X86_32Architecture)



M68k



LoongArch64



Mips32(Mips32Architecture)



Mips64(Mips64Architecture)



Msp430



Nvptx64



Pulley32



Pulley64



Pulley32be



Pulley64be



Powerpc



Powerpc64



Powerpc64le



Riscv32(Riscv32Architecture)



Riscv64(Riscv64Architecture)



S390x



Sparc



Sparc64



Sparcv9



Wasm32



Wasm64



X86_64



X86_64h

x86_64 target that only supports Haswell-compatible Intel chips.



XTensa



Clever(CleverArchitecture)

Implementations



impl Architecture

pub const fn host() -> Architecture

Return the architecture for the current host.



impl Architecture

pub fn endianness(self) -> Result<Endianness, ()>

Return the endianness of this architecture.

pub fn pointer_width(self) -> Result<PointerWidth, ()>

Return the pointer bit width of this target’s architecture.

This function is only aware of the CPU architecture so it is not aware of ilp32 and x32 ABIs.

pub fn is_clever(&self) -> bool

Checks if this Architecture is some variant of Clever-ISA

pub fn into_str(self) -> Cow<'static, str>

Convert into a string