pub enum BackendAsyncFunctionEnvHandleMut<T> {
Sys(AsyncFunctionEnvHandleMut<T>),
}Expand description
A mutable handle to the FunctionEnv in an BackendAsyncFunctionEnvMut.
Variants
Sys(AsyncFunctionEnvHandleMut<T>)
The function environment handle for the sys runtime.
Implementations
Sourceimpl<T: 'static> BackendAsyncFunctionEnvHandleMut<T>
impl<T: 'static> BackendAsyncFunctionEnvHandleMut<T>
Sourcepub fn data_mut(&mut self) -> &mut T
pub fn data_mut(&mut self) -> &mut T
Returns a mutable reference to the host state in this function environment.
Sourcepub fn data_and_store_mut(&mut self) -> (&mut T, &mut impl AsStoreMut)
pub fn data_and_store_mut(&mut self) -> (&mut T, &mut impl AsStoreMut)
Returns both the host state and the attached StoreMut
Sourcepub fn as_function_env_mut(&mut self) -> BackendFunctionEnvMut<'_, T>
pub fn as_function_env_mut(&mut self) -> BackendFunctionEnvMut<'_, T>
Borrows a new BackendFunctionEnvMut from this
BackendAsyncFunctionEnvHandleMut.