pub enum BackendAsyncFunctionEnvMut<T> {
Sys(AsyncFunctionEnvMut<T>),
}Expand description
A shared handle to a FunctionEnv, suitable for use
in async imports.
Variants
Sys(AsyncFunctionEnvMut<T>)
The function environment for the sys runtime.
Implementations
Sourceimpl<T: 'static> BackendAsyncFunctionEnvMut<T>
impl<T: 'static> BackendAsyncFunctionEnvMut<T>
Sourcepub async fn read(&self) -> BackendAsyncFunctionEnvHandle<T>
pub async fn read(&self) -> BackendAsyncFunctionEnvHandle<T>
Waits for a store lock and returns a read-only handle to the function environment.
Sourcepub async fn write(&self) -> BackendAsyncFunctionEnvHandleMut<T>
pub async fn write(&self) -> BackendAsyncFunctionEnvHandleMut<T>
Waits for a store lock and returns a mutable handle to the function environment.
Sourcepub fn as_ref(&self) -> BackendFunctionEnv<T>
pub fn as_ref(&self) -> BackendFunctionEnv<T>
Borrows a new immutable reference
Sourcepub fn as_store_async(&self) -> impl AsStoreAsync + 'static
pub fn as_store_async(&self) -> impl AsStoreAsync + 'static
Creates an AsStoreAsync from this BackendAsyncFunctionEnvMut.