Struct MemoryBuffer

pub(crate) struct MemoryBuffer<'a>(pub(crate) BackendMemoryBuffer<'a>);
Underlying buffer for a memory.

Tuple Fields

0: BackendMemoryBuffer<'a>

Implementations

Source

impl MemoryBuffer<'_>

pub(crate) fn read( &self, offset: u64, buf: &mut [u8], ) -> Result<(), MemoryAccessError>

pub(crate) fn read_uninit<'b>( &self, offset: u64, buf: &'b mut [MaybeUninit<u8>], ) -> Result<&'b mut [u8], MemoryAccessError>

pub(crate) fn write( &self, offset: u64, data: &[u8], ) -> Result<(), MemoryAccessError>

pub(crate) fn len(&self) -> usize

pub(crate) fn base(&self) -> *mut u8

pub(crate) fn is_owned(&self) -> bool

This is used to determine if the buffer is owned by the memory.

This is only useful for JS memory buffers, as they will slowdown if we always need to own the memory in other engines.