pub(crate) enum BackendTag {
Sys(Tag),
}Variants
Implementations
Sourceimpl BackendTag
impl BackendTag
Sourcepub fn new<P: Into<Box<[Type]>>>(store: &mut impl AsStoreMut, params: P) -> Self
pub fn new<P: Into<Box<[Type]>>>(store: &mut impl AsStoreMut, params: P) -> Self
Create a new tag with event of type P -> [], that is a function that takes parameters P
and has no return value.
Sourcepub fn ty(&self, store: &impl AsStoreRef) -> TagType
pub fn ty(&self, store: &impl AsStoreRef) -> TagType
Returns the TagType of the tag.
pub(crate) fn from_vm_extern( store: &mut impl AsStoreMut, vm_extern: VMExternTag, ) -> Self
Sourcepub fn is_from_store(&self, store: &impl AsStoreRef) -> bool
pub fn is_from_store(&self, store: &impl AsStoreRef) -> bool
Checks whether this tag can be used with the given context.
Sourcepub(crate) fn to_vm_extern(&self) -> VMExtern
pub(crate) fn to_vm_extern(&self) -> VMExtern
Create a VMExtern from self.