Enum ExternType
pub enum ExternType {
Function(FunctionType),
Global(GlobalType),
Table(TableType),
Memory(MemoryType),
Tag(TagType),
}Expand description
A list of all possible types which can be externally referenced from a WebAssembly module.
This list can be found in ImportType or ExportType, so these types
can either be imported or exported.
Variants
Function(FunctionType)
This external type is the type of a WebAssembly function.
Global(GlobalType)
This external type is the type of a WebAssembly global.
Table(TableType)
This external type is the type of a WebAssembly table.
Memory(MemoryType)
This external type is the type of a WebAssembly memory.
Tag(TagType)
This external type is the type of a WebAssembly tag.
Implementations
impl ExternType
impl ExternType
pub fn func(&self) -> Option<&FunctionType>
pub fn func(&self) -> Option<&FunctionType>
Attempt to return the underlying type of this external type,
returning None if it is a different type.
pub fn unwrap_func(&self) -> &FunctionType
pub fn unwrap_func(&self) -> &FunctionType
Returns the underlying descriptor of this ExternType, panicking
if it is a different type.
Panics
Panics if self is not of the right type.
pub fn global(&self) -> Option<&GlobalType>
pub fn global(&self) -> Option<&GlobalType>
Attempt to return the underlying type of this external type,
returning None if it is a different type.
pub fn unwrap_global(&self) -> &GlobalType
pub fn unwrap_global(&self) -> &GlobalType
Returns the underlying descriptor of this ExternType, panicking
if it is a different type.
Panics
Panics if self is not of the right type.
pub fn table(&self) -> Option<&TableType>
pub fn table(&self) -> Option<&TableType>
Attempt to return the underlying type of this external type,
returning None if it is a different type.
pub fn unwrap_table(&self) -> &TableType
pub fn unwrap_table(&self) -> &TableType
Returns the underlying descriptor of this ExternType, panicking
if it is a different type.
Panics
Panics if self is not of the right type.
pub fn memory(&self) -> Option<&MemoryType>
pub fn memory(&self) -> Option<&MemoryType>
Attempt to return the underlying type of this external type,
returning None if it is a different type.
pub fn unwrap_memory(&self) -> &MemoryType
pub fn unwrap_memory(&self) -> &MemoryType
Returns the underlying descriptor of this ExternType, panicking
if it is a different type.
Panics
Panics if self is not of the right type.
pub fn is_compatible_with(
&self,
other: &ExternType,
runtime_size: Option<u32>,
) -> bool
pub fn is_compatible_with( &self, other: &ExternType, runtime_size: Option<u32>, ) -> bool
Check if two externs are compatible