Enum Mutability
#[repr(u8)]pub enum Mutability {
Const = 0,
Var = 1,
}Expand description
Indicator of whether a global is mutable or not
Variants
Const = 0
The global is constant and its value does not change
Var = 1
The value of the global can change over time
Implementations
impl Mutability
impl Mutability
pub fn is_mutable(self) -> bool
pub fn is_mutable(self) -> bool
Returns a boolean indicating if the enum is set to mutable.