pub enum RuntimeErrorDisplay<'a> {
Exception(Vec<Value>, &'a [FrameInfo]),
Other(&'a RuntimeError),
}Expand description
A displayable version of the RuntimeError that also shows exception payloads.
Variants
Exception(Vec<Value>, &'a [FrameInfo])
The error is an uncaught exception, with its payload and trace.
Other(&'a RuntimeError)
The error is not an exception, just display it.