pub struct MemoryOps {
ops: Option<Arc<dyn SharedMemoryOps + Send + Sync>>,
}Expand description
Shared memory operations that do not hold the underlying memory alive.
This handle is intended for operations, such as waking atomic waiters, that may be attempted after the original memory owner has started shutting down.
Fields
ops: Option<Arc<dyn SharedMemoryOps + Send + Sync>>Implementations
Sourceimpl MemoryOps
impl MemoryOps
Sourcepub fn notify(
&self,
location: MemoryLocation,
count: u32,
) -> Result<u32, AtomicsError>
pub fn notify( &self, location: MemoryLocation, count: u32, ) -> Result<u32, AtomicsError>
Notify up to count waiters waiting for the memory location.
Sourcepub fn wait(
&self,
location: MemoryLocation,
timeout: Option<Duration>,
) -> Result<u32, AtomicsError>
pub fn wait( &self, location: MemoryLocation, timeout: Option<Duration>, ) -> Result<u32, AtomicsError>
Wait for the memory location to be notified.
Sourcepub fn disable_atomics(&self) -> Result<(), AtomicsError>
pub fn disable_atomics(&self) -> Result<(), AtomicsError>
Disable atomics for this memory if it is still alive.
All subsequent atomic wait calls will produce a trap.
Sourcepub fn wake_all_atomic_waiters(&self) -> Result<(), AtomicsError>
pub fn wake_all_atomic_waiters(&self) -> Result<(), AtomicsError>
Wake up all atomic waiters if the memory is still alive.