Struct TagType
pub struct TagType {
pub kind: TagKind,
pub params: Box<[Type]>,
}Expand description
The signature of a tag that is either implemented in a Wasm module or exposed to Wasm by the host.
Fields
kind: TagKindThe kind of the tag.
params: Box<[Type]>The parameters of the tag
Implementations