Struct Singlepass
pub struct Singlepass {
pub(crate) enable_nan_canonicalization: bool,
pub(crate) middlewares: Vec<Arc<dyn ModuleMiddleware>>,
pub(crate) callbacks: Option<SinglepassCallbacks>,
pub num_threads: NonZero<usize>,
}Fields
enable_nan_canonicalization: boolmiddlewares: Vec<Arc<dyn ModuleMiddleware>>callbacks: Option<SinglepassCallbacks>num_threads: NonZero<usize>The number of threads to use for compilation.
Implementations
impl Singlepass
impl Singlepass
pub fn new() -> Singlepass
pub fn new() -> Singlepass
Creates a new configuration object with the default configuration specified.
pub fn canonicalize_nans(&mut self, enable: bool) -> &mut Singlepass
pub fn callbacks(
&mut self,
callbacks: Option<SinglepassCallbacks>,
) -> &mut Singlepass
pub fn callbacks( &mut self, callbacks: Option<SinglepassCallbacks>, ) -> &mut Singlepass
Callbacks that will triggered in the different compilation phases in Singlepass.
pub fn num_threads(&mut self, num_threads: NonZero<usize>) -> &mut Singlepass
pub fn num_threads(&mut self, num_threads: NonZero<usize>) -> &mut Singlepass
Set the number of threads to use for compilation.