Struct FunctionBodyPtr
#[repr(transparent)]pub struct FunctionBodyPtr(pub *const VMFunctionBody);Expand description
A safe wrapper around VMFunctionBody.
Tuple Fields
0: *const VMFunctionBodyTrait Implementations
impl Clone for FunctionBodyPtr
impl Clone for FunctionBodyPtr
fn clone(&self) -> FunctionBodyPtr
fn clone(&self) -> FunctionBodyPtr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for FunctionBodyPtr
impl Debug for FunctionBodyPtr
impl Deref for FunctionBodyPtr
impl Deref for FunctionBodyPtr
type Target = *const VMFunctionBody
type Target = *const VMFunctionBody
The resulting type after dereferencing.
fn deref(&self) -> &<FunctionBodyPtr as Deref>::Target
fn deref(&self) -> &<FunctionBodyPtr as Deref>::Target
Dereferences the value.
impl Copy for FunctionBodyPtr
impl Send for FunctionBodyPtr
Safety
The VMFunctionBody that this points to is opaque, so there’s no data to read or write through this pointer. This is essentially a usize.
impl Sync for FunctionBodyPtr
Safety
The VMFunctionBody that this points to is opaque, so there’s no data to read or write through this pointer. This is essentially a usize.