Struct VMContext
#[repr(C, align(16))]pub struct VMContext {}Expand description
The VM “context”, which is pointed to by the vmctx arg in the compiler.
This has information about globals, memories, tables, and other runtime
state associated with the current instance.
The struct here is empty, as the sizes of these fields are dynamic, and we can’t describe them in Rust’s type system. Sufficient memory is allocated at runtime.
TODO: We could move the globals into the vmctx allocation too.