Struct VMDynamicFunctionContext
#[repr(C)]pub struct VMDynamicFunctionContext<T> {
pub address: *const VMFunctionBody,
pub ctx: T,
}Expand description
The VMDynamicFunctionContext is the context that dynamic
functions will receive when called (rather than vmctx).
A dynamic function is a function for which we don’t know the signature
until runtime.
As such, we need to expose the dynamic function context
containing the relevant context for running the function indicated
in address.
Fields
address: *const VMFunctionBodyThe address of the inner dynamic function.
Note: The function must be on the form of
(*mut T, SignatureIndex, *mut i128).
ctx: TThe context that the inner dynamic function will receive.