VMOwnedMemory

Struct VMOwnedMemory 

pub struct VMOwnedMemory {
    mmap: WasmMmap,
    config: VMMemoryConfig,
}
A linear memory instance.

Fields

mmap: WasmMmapconfig: VMMemoryConfig

Implementations



impl VMOwnedMemory

pub fn new( memory: &MemoryType, style: &MemoryStyle, ) -> Result<VMOwnedMemory, MemoryError>

Create a new linear memory instance with specified minimum and maximum number of wasm pages.

This creates a Memory with owned metadata: this can be used to create a memory that will be imported into Wasm modules.

pub fn new_with_file( memory: &MemoryType, style: &MemoryStyle, backing_file: PathBuf, memory_type: MmapType, ) -> Result<VMOwnedMemory, MemoryError>

Create a new linear memory instance with specified minimum and maximum number of wasm pages that is backed by a memory file. When set to private the file will be remaining in memory and never flush to disk, when set to shared the memory will be flushed to disk.

This creates a Memory with owned metadata: this can be used to create a memory that will be imported into Wasm modules.

pub unsafe fn from_definition( memory: &MemoryType, style: &MemoryStyle, vm_memory_location: NonNull<VMMemoryDefinition>, ) -> Result<VMOwnedMemory, MemoryError>

Create a new linear memory instance with specified minimum and maximum number of wasm pages.

This creates a Memory with metadata owned by a VM, pointed to by vm_memory_location: this can be used to create a local memory.

Safety
  • vm_memory_location must point to a valid location in VM memory.

pub unsafe fn from_definition_with_file( memory: &MemoryType, style: &MemoryStyle, vm_memory_location: NonNull<VMMemoryDefinition>, backing_file: Option<PathBuf>, memory_type: MmapType, ) -> Result<VMOwnedMemory, MemoryError>

Create a new linear memory instance with specified minimum and maximum number of wasm pages that is backed by a file. When set to private the file will be remaining in memory and never flush to disk, when set to shared the memory will be flushed to disk.

This creates a Memory with metadata owned by a VM, pointed to by vm_memory_location: this can be used to create a local memory.

Safety
  • vm_memory_location must point to a valid location in VM memory.

pub fn to_shared(self) -> VMSharedMemory

Converts this owned memory into shared memory

pub fn copy(&self) -> Result<VMOwnedMemory, MemoryError>

Copies this memory to a new memory