pub type VMExternFunction = InternalStoreHandle<VMFunction>;Expand description
The type of extern functions in the sys VM.
Aliased Type
#[repr(transparent)]pub struct VMExternFunction { /* private fields */ }pub type VMExternFunction = InternalStoreHandle<VMFunction>;The type of extern functions in the sys VM.
#[repr(transparent)]pub struct VMExternFunction { /* private fields */ }