pub type VMExternMemory = InternalStoreHandle<VMMemory>;Expand description
The type of extern memories in the sys VM.
Aliased Type
#[repr(transparent)]pub struct VMExternMemory { /* private fields */ }pub type VMExternMemory = InternalStoreHandle<VMMemory>;The type of extern memories in the sys VM.
#[repr(transparent)]pub struct VMExternMemory { /* private fields */ }