pub type VMExternTable = InternalStoreHandle<VMTable>;Expand description
The type of extern tables in the sys VM.
Aliased Type
#[repr(transparent)]pub struct VMExternTable { /* private fields */ }pub type VMExternTable = InternalStoreHandle<VMTable>;The type of extern tables in the sys VM.
#[repr(transparent)]pub struct VMExternTable { /* private fields */ }