pub struct WasmRefAccess<'a, T>where
T: ValueType,{
pub(crate) is_owned: bool,
pub(crate) ptr: WasmRef<'a, T>,
pub(crate) buf: RefCow<'a, T>,
}Expand description
Provides direct memory access to a piece of memory that is owned by WASM
Fields
is_owned: boolptr: WasmRef<'a, T>buf: RefCow<'a, T>Implementations
Sourceimpl<T> WasmRefAccess<'_, T>where
T: ValueType,
impl<T> WasmRefAccess<'_, T>where
T: ValueType,
Sourcepub fn as_mut_uninit(&mut self) -> &mut MaybeUninit<T>
pub fn as_mut_uninit(&mut self) -> &mut MaybeUninit<T>
Returns a reference to an unitialized reference to this value
Sourceimpl<'a, T> WasmRefAccess<'a, T>where
T: ValueType,
impl<'a, T> WasmRefAccess<'a, T>where
T: ValueType,
pub(crate) fn new( ptr: WasmRef<'a, T>, is_owned: bool, ) -> Result<Self, MemoryAccessError>
pub(crate) fn new_borrowed( ptr: WasmRef<'a, T>, ) -> Result<Self, MemoryAccessError>
pub(crate) fn new_owned(ptr: WasmRef<'a, T>) -> Result<Self, MemoryAccessError>