pub enum VMExceptionRef {
Sys(VMExceptionRef),
}Variants
Sys(VMExceptionRef)
The implementation from the sys backend.
Implementations
Sourceimpl VMExceptionRef
impl VMExceptionRef
Sourcepub fn unwrap_sys(self) -> VMExceptionRef
pub fn unwrap_sys(self) -> VMExceptionRef
Unwraps this value to the VMExceptionRef::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_ref(&self) -> &VMExceptionRef
pub fn unwrap_sys_ref(&self) -> &VMExceptionRef
Unwraps this reference to the VMExceptionRef::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_mut(&mut self) -> &mut VMExceptionRef
pub fn unwrap_sys_mut(&mut self) -> &mut VMExceptionRef
Unwraps this mutable reference to the VMExceptionRef::Sys variant.
Panics if this value is of any other type.