pub enum VMExtern {
Sys(VMExtern),
}Variants
Implementations
Sourceimpl VMExtern
impl VMExtern
Sourcepub fn unwrap_sys(self) -> VMExtern
pub fn unwrap_sys(self) -> VMExtern
Unwraps this value to the VMExtern::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_ref(&self) -> &VMExtern
pub fn unwrap_sys_ref(&self) -> &VMExtern
Unwraps this reference to the VMExtern::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_mut(&mut self) -> &mut VMExtern
pub fn unwrap_sys_mut(&mut self) -> &mut VMExtern
Unwraps this mutable reference to the VMExtern::Sys variant.
Panics if this value is of any other type.