pub enum VMExternGlobal {
Sys(VMExternGlobal),
}Variants
Sys(VMExternGlobal)
The implementation from the sys backend.
Implementations
Sourceimpl VMExternGlobal
impl VMExternGlobal
Sourcepub fn unwrap_sys(self) -> VMExternGlobal
pub fn unwrap_sys(self) -> VMExternGlobal
Unwraps this value to the VMExternGlobal::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_ref(&self) -> &VMExternGlobal
pub fn unwrap_sys_ref(&self) -> &VMExternGlobal
Unwraps this reference to the VMExternGlobal::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_mut(&mut self) -> &mut VMExternGlobal
pub fn unwrap_sys_mut(&mut self) -> &mut VMExternGlobal
Unwraps this mutable reference to the VMExternGlobal::Sys variant.
Panics if this value is of any other type.