pub enum VMExternRef {
Sys(VMExternRef),
}Variants
Sys(VMExternRef)
The implementation from the sys backend.
Implementations
Sourceimpl VMExternRef
impl VMExternRef
Sourceimpl VMExternRef
impl VMExternRef
Sourcepub fn unwrap_sys(self) -> VMExternRef
pub fn unwrap_sys(self) -> VMExternRef
Unwraps this value to the VMExternRef::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_ref(&self) -> &VMExternRef
pub fn unwrap_sys_ref(&self) -> &VMExternRef
Unwraps this reference to the VMExternRef::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_mut(&mut self) -> &mut VMExternRef
pub fn unwrap_sys_mut(&mut self) -> &mut VMExternRef
Unwraps this mutable reference to the VMExternRef::Sys variant.
Panics if this value is of any other type.