pub enum VMExternTable {
Sys(VMExternTable),
}Variants
Sys(VMExternTable)
The implementation from the sys backend.
Implementations
Sourceimpl VMExternTable
impl VMExternTable
Sourcepub fn unwrap_sys(self) -> VMExternTable
pub fn unwrap_sys(self) -> VMExternTable
Unwraps this value to the VMExternTable::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_ref(&self) -> &VMExternTable
pub fn unwrap_sys_ref(&self) -> &VMExternTable
Unwraps this reference to the VMExternTable::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_mut(&mut self) -> &mut VMExternTable
pub fn unwrap_sys_mut(&mut self) -> &mut VMExternTable
Unwraps this mutable reference to the VMExternTable::Sys variant.
Panics if this value is of any other type.