#[repr(C)]pub enum VMFunctionCallback {
Sys(VMFunctionCallback),
}Expand description
The enum for all those VM values of this kind.
Variants
Sys(VMFunctionCallback)
Implementations
Sourceimpl VMFunctionCallback
impl VMFunctionCallback
Sourcepub fn into_sys(self) -> VMFunctionCallback
pub fn into_sys(self) -> VMFunctionCallback
Consume self into a sys VM kind.
Sourcepub fn as_sys(&self) -> &VMFunctionCallback
pub fn as_sys(&self) -> &VMFunctionCallback
Convert a reference to self into a reference to the same sys VM kind.
Sourcepub fn as_sys_mut(&mut self) -> &mut VMFunctionCallback
pub fn as_sys_mut(&mut self) -> &mut VMFunctionCallback
Convert a mutable reference to self into a mutable reference to the same sys VM kind.