pub enum VMTrampoline {
Sys(VMTrampoline),
}Variants
Sys(VMTrampoline)
The implementation from the sys backend.
Implementations
Sourceimpl VMTrampoline
impl VMTrampoline
Sourcepub fn unwrap_sys(self) -> VMTrampoline
pub fn unwrap_sys(self) -> VMTrampoline
Unwraps this value to the VMTrampoline::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_ref(&self) -> &VMTrampoline
pub fn unwrap_sys_ref(&self) -> &VMTrampoline
Unwraps this reference to the VMTrampoline::Sys variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_sys_mut(&mut self) -> &mut VMTrampoline
pub fn unwrap_sys_mut(&mut self) -> &mut VMTrampoline
Unwraps this mutable reference to the VMTrampoline::Sys variant.
Panics if this value is of any other type.