pub struct AsyncFunctionEnvHandleMut<T> {
write_lock: StoreAsyncWriteLock,
pub(crate) func_env: FunctionEnv<T>,
}Expand description
A mutable handle to the FunctionEnv in an AsyncFunctionEnvMut.
Fields
write_lock: StoreAsyncWriteLockfunc_env: FunctionEnv<T>Implementations
Sourceimpl<T: 'static> AsyncFunctionEnvHandleMut<T>
impl<T: 'static> AsyncFunctionEnvHandleMut<T>
Sourcepub fn data_mut(&mut self) -> &mut T
pub fn data_mut(&mut self) -> &mut T
Returns a mutable reference to the host state in this function environment.
Sourcepub fn data_and_store_mut(&mut self) -> (&mut T, &mut impl AsStoreMut)
pub fn data_and_store_mut(&mut self) -> (&mut T, &mut impl AsStoreMut)
Returns both the host state and the attached StoreMut
Sourcepub fn as_function_env_mut(&mut self) -> FunctionEnvMut<'_, T>
pub fn as_function_env_mut(&mut self) -> FunctionEnvMut<'_, T>
Borrows a new FunctionEnvMut from this AsyncFunctionEnvHandleMut.