Enum CpuFeature
pub enum CpuFeature {
Show 15 variants
SSE2,
SSE3,
SSSE3,
SSE41,
SSE42,
POPCNT,
AVX,
BMI1,
BMI2,
AVX2,
AVX512DQ,
AVX512VL,
AVX512F,
LZCNT,
NEON,
}Expand description
The nomenclature is inspired by the cpuid crate.
The list of supported features was initially retrieved from
cranelift-native.
The CpuFeature enum values are likely to grow closer to the
original cpuid. However, we prefer to start small and grow from there.
If you would like to use a flag that doesn’t exist yet here, please open a PR.
Variants
Implementations
impl CpuFeature
impl CpuFeature
pub fn for_host() -> EnumSet<CpuFeature>
pub fn for_host() -> EnumSet<CpuFeature>
Retrieves the features for the current Host
pub fn set() -> EnumSet<CpuFeature>
pub fn set() -> EnumSet<CpuFeature>
Retrieves an empty set of CpuFeatures.
pub fn all() -> EnumSet<CpuFeature>
pub fn all() -> EnumSet<CpuFeature>
Build a set of all available CpuFeatures.