pub(crate) struct StoreInner {
pub(crate) objects: StoreObjects,
pub(crate) store: BackendStore,
pub(crate) on_called: Option<Box<dyn FnOnce(StoreMut<'_>) -> Result<OnCalledAction, Box<dyn Error + Send + Sync>>>>,
}Expand description
We require the context to have a fixed memory address for its lifetime since various bits of the VM have raw pointers that point back to it. Hence we wrap the actual context in a box.
Fields
objects: StoreObjectsstore: BackendStoreon_called: Option<Box<dyn FnOnce(StoreMut<'_>) -> Result<OnCalledAction, Box<dyn Error + Send + Sync>>>>Trait Implementations
Sourceimpl AsStoreMut for StoreInner
impl AsStoreMut for StoreInner
Sourcefn as_store_mut(&mut self) -> StoreMut<'_>
fn as_store_mut(&mut self) -> StoreMut<'_>
Returns a
StoreMut pointing to the underlying context.Sourcefn objects_mut(&mut self) -> &mut StoreObjects
fn objects_mut(&mut self) -> &mut StoreObjects
Returns the ObjectMutable
Sourceimpl AsStoreRef for StoreInner
impl AsStoreRef for StoreInner
Sourcefn as_store_ref(&self) -> StoreRef<'_>
fn as_store_ref(&self) -> StoreRef<'_>
Returns a
StoreRef pointing to the underlying context.Sourcefn as_store_async(&self) -> Option<impl AsStoreAsync + 'static>
fn as_store_async(&self) -> Option<impl AsStoreAsync + 'static>
Returns a
StoreAsync if the current
context is asynchronous. The store will be locked since
it’s already active in the current context, but can be used
to spawn new coroutines via
Function::call_async.Auto Trait Implementations
impl Freeze for StoreInner
impl !RefUnwindSafe for StoreInner
impl !Send for StoreInner
impl !Sync for StoreInner
impl Unpin for StoreInner
impl !UnwindSafe for StoreInner