Struct FunctionType
pub struct FunctionType {
params: Box<[Type]>,
results: Box<[Type]>,
}Expand description
The signature of a function that is either implemented in a Wasm module or exposed to Wasm by the host.
WebAssembly functions can have 0 or more parameters and results.
Fields
params: Box<[Type]>results: Box<[Type]>Implementations
impl FunctionType
impl FunctionType
pub fn new<Params, Returns>(params: Params, returns: Returns) -> FunctionType
pub fn new<Params, Returns>(params: Params, returns: Returns) -> FunctionType
Creates a new Function Type with the given parameter and return types.