Struct GlobalType
pub struct GlobalType {
pub ty: Type,
pub mutability: Mutability,
}Expand description
WebAssembly global.
Fields
ty: TypeThe type of the value stored in the global.
mutability: MutabilityA flag indicating whether the value may change at runtime.
Implementations
impl GlobalType
A WebAssembly global descriptor.
impl GlobalType
A WebAssembly global descriptor.
This type describes an instance of a global in a WebAssembly
module. Globals are local to an Instance and are either
immutable or mutable.
pub fn new(ty: Type, mutability: Mutability) -> GlobalType
pub fn new(ty: Type, mutability: Mutability) -> GlobalType
Create a new Global variable
Usage:
use wasmer_types::{GlobalType, Type, Mutability};
// An I32 constant global
let global = GlobalType::new(Type::I32, Mutability::Const);
// An I64 mutable global
let global = GlobalType::new(Type::I64, Mutability::Var);Trait Implementations
impl Archive for GlobalTypewhere
Type: Archive,
Mutability: Archive,
impl Archive for GlobalTypewhere
Type: Archive,
Mutability: Archive,
const COPY_OPTIMIZATION: CopyOptimization<GlobalType>
const COPY_OPTIMIZATION: CopyOptimization<GlobalType>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moretype Resolver = GlobalTypeResolver
type Resolver = GlobalTypeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
fn resolve(
&self,
resolver: <GlobalType as Archive>::Resolver,
out: Place<<GlobalType as Archive>::Archived>,
)
fn resolve( &self, resolver: <GlobalType as Archive>::Resolver, out: Place<<GlobalType as Archive>::Archived>, )
Creates the archived version of this value at the given position and
writes it to the given output. Read more
impl Clone for GlobalType
impl Clone for GlobalType
fn clone(&self) -> GlobalType
fn clone(&self) -> GlobalType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for GlobalType
impl Debug for GlobalType
impl<'de> Deserialize<'de> for GlobalType
impl<'de> Deserialize<'de> for GlobalType
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GlobalType, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GlobalType, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<__D> Deserialize<GlobalType, __D> for <GlobalType as Archive>::Archivedwhere
__D: Fallible + ?Sized,
Type: Archive,
<Type as Archive>::Archived: Deserialize<Type, __D>,
Mutability: Archive,
<Mutability as Archive>::Archived: Deserialize<Mutability, __D>,
impl<__D> Deserialize<GlobalType, __D> for <GlobalType as Archive>::Archivedwhere
__D: Fallible + ?Sized,
Type: Archive,
<Type as Archive>::Archived: Deserialize<Type, __D>,
Mutability: Archive,
<Mutability as Archive>::Archived: Deserialize<Mutability, __D>,
fn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GlobalType, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GlobalType, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Display for GlobalType
impl Display for GlobalType
impl Hash for GlobalType
impl Hash for GlobalType
impl PartialEq<ArchivedGlobalType> for GlobalTypewhere
Type: Archive,
Mutability: Archive,
<Type as Archive>::Archived: PartialEq<Type>,
<Mutability as Archive>::Archived: PartialEq<Mutability>,
impl PartialEq<ArchivedGlobalType> for GlobalTypewhere
Type: Archive,
Mutability: Archive,
<Type as Archive>::Archived: PartialEq<Type>,
<Mutability as Archive>::Archived: PartialEq<Mutability>,
impl PartialEq for GlobalType
impl PartialEq for GlobalType
impl<__S> Serialize<__S> for GlobalType
impl<__S> Serialize<__S> for GlobalType
fn serialize(
&self,
serializer: &mut __S,
) -> Result<<GlobalType as Archive>::Resolver, <__S as Fallible>::Error>
fn serialize( &self, serializer: &mut __S, ) -> Result<<GlobalType as Archive>::Resolver, <__S as Fallible>::Error>
Writes the dependencies for the object and returns a resolver that can
create the archived type.
impl Serialize for GlobalType
impl Serialize for GlobalType
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for GlobalType
impl Eq for GlobalType
impl StructuralPartialEq for GlobalType